from pathlib import Path

from langchain_community.document_loaders import TextLoader
from langchain_community.vectorstores import FAISS
from langchain_core.documents.base import Document
from langchain_core.vectorstores import VectorStoreRetriever
from langchain_ollama.embeddings import OllamaEmbeddings


def documents_from_list(file_paths: list[Path | str]) -> list[Document]:
    return [doc for file_path in file_paths for doc in TextLoader(file_path).load()]


def create_retriever(
    file_paths: list[Path | str], embedding_model: str
) -> VectorStoreRetriever:
    embeddings = OllamaEmbeddings(model=embedding_model)
    vectorstore = FAISS.from_documents(documents_from_list(file_paths), embeddings)
    return vectorstore.as_retriever()


def get_context_from_store(message: str, retriever: VectorStoreRetriever):
    docs = retriever.get_relevant_documents(message)
    return "\n\n".join([doc.page_content for doc in docs])


# TODO: Currently the vector store is reconstructed each time. Add logic for saving/updating the
# vector store instead of reconstructing it each time the code is executed.
